import React, { useEffect, useRef, useState } from 'react'
import ReactSignatureCanvas from 'react-signature-canvas'
import Drag from '../../../components/Drag'
import { UploadFileReturnUrl, getUserSignature, SaveUserSignature } from '../../../../apis/process'
import styles from './index.less'
import { Button, Checkbox } from 'antd'
import moment from 'moment'
const Signature = (props) => {

  const userID = window?.globalConfig?.userInfo?.OID || 1;
  const { addons, value, onChange, schema } = props
  const { disabled, presetValue, showDate , isShowSave } = schema
  const [visible, setVisible] = useState(false)
  const [count, setCount] = useState(0)
  const [checked, setChecked] = useState(false)
  const [signature, setSignature] = useState('')
  const canvasRef = useRef(null)
  const open = () => {
    if (addons) {
      getSignature()
      setVisible(true)
    }
  }

  const onOk = async () => {
    if (disabled) {
      setVisible(false)
    } else {
      if (addons) {
        const dataUrl = canvasRef.current.toDataURL(); // 获取 Base64 编码的字符串
        const byteString = atob(dataUrl.split(',')[1]); // 将 Base64 编码的字符串转换为字节数组
        const mimeString = dataUrl.split(',')[0].split(':')[1].split(';')[0]; // 获取 MIME 类型
        const ab = new ArrayBuffer(byteString.length);
        const ia = new Uint8Array(ab);
        for (let i = 0; i < byteString.length; i++) {
          ia[i] = byteString.charCodeAt(i);
        }
        const file = new Blob([ab], { type: mimeString }); // 将字节数组转换为文件流
        const formData = new FormData(); // 创建表单数据对象
        formData.append('file', file, 'signature.png'); // 添加文件流到表
        const { code, data } = await UploadFileReturnUrl(formData)
        if (code === 0) {
          onChange(data)
          setVisible(false)
          if (checked) {
            saveSignature(data)
          }
        } else {
          message.error('生成图片失败!')
        }
      }
    }
  }

  const saveSignature = async (data) => {
    const { code } = await SaveUserSignature({ userId: userID, value: data })
    if (code === 0) {
      console.log('保存电子签章')
    }
  }

  const getSignature = async () => {
    const { code, data } = await getUserSignature(userID)
    if (code === 0) {
      setSignature(data)
    }
  }

  const getValues = () => {
    onChange(signature)
    setVisible(false)
  }

  const checkChange = (e) => {
    setChecked(e.target.checked)
  }

  useEffect(()=>{
    if (canvasRef.current && showDate) {
      const canvas = canvasRef.current.getCanvas(); // 获取底层的Canvas元素
      const ctx = canvas.getContext('2d');

      // 在这里绘制你的水印
      ctx.font = "20px 'Brush Script MT', 'Lucida Handwriting', cursive";
      ctx.fillStyle = "black";
      ctx.textAlign = "left";
      ctx.fillText(moment().format('YYYY.MM.DD'), canvas.width / 1.3, canvas.height - 20);
    }else{
     setTimeout(() => {
      setCount(count + 1)
     }, 50);
    }
  }, [canvasRef.current])

  useEffect(() => {
    addons?.setValue(addons?.dataPath, presetValue || '')
  }, [presetValue])

  return (
    <div className={styles.signature}>
      <div className={styles.content}>
        {
          value ? (
            <img onClick={open} src={`${window.origin}/PandaWorkFlow/WorkFlow/AccountManage/DownloadFiles?filePath=${value}`}></img>
          ) : (
            disabled ? null : <div onClick={open} className={styles.text}>点击签名</div>
          )
        }
      </div>
      <Drag
        title={'手写签名'}
        visible={visible}
        onCancel={() => setVisible(false)}
        footer={
          <div className={styles.footer} style={{ display: 'flex', justifyContent: 'space-between' }}>
            {
              !isShowSave && (
                <Checkbox onChange={checkChange} checked={checked}>保存到电子签章中</Checkbox>
              )
            }
            <div className={styles.right}>
              <Button onClick={() => setVisible(false)}>取消</Button>
              {signature ? <Button type='primary' ghost onClick={() => getValues()}>电子签章</Button> : null}
              <Button type='primary' onClick={() => onOk()}>确定</Button>
            </div>
          </div>
        }
        destroyOnClose
      >
        {
          disabled ? (
            <img src={`${window.origin}/PandaWorkFlow/WorkFlow/AccountManage/DownloadFiles?filePath=${value}`}></img>
          ) : (
            <div style={{ background: '#F1F1F1', borderRadius: '5px' }}>
              <ReactSignatureCanvas
                ref={canvasRef}
                canvasProps={{ width: 500, height: 300 }}
              />
            </div>
          )
        }
      </Drag>
    </div>
  )

}

export default Signature
